 %***********************************************************************
%      SUBROUTINE ADAMS
%************************************************************************

function []  = ADAMS()
    % CONST
    %%% QCONST
    global  PAI RAD DEG RE CVLCTY

    % INPUT
    %%% QPARAM
    global  RRMIN RRMAX ERRR ERRA HMIN DISOUT ...
        NLPMAX
    %%% QINIT
    global  R0 T0 P0 E0 D0 F0
    %%% QPATH
    global  FKC DEL EPS

    % OUTPUT
    %%% QCOND
    global  L LL NN NLOOP A

    % Variables below are only used in the ADAMS method.
    %%% QADAM
    global  Y P F ...
        H HOLD WT PHI ...
        K KOLD IPHASE IFAIL ...
        % str21

    A = 0;
    OUT0

    %*** Initialization of Y
    Y(1)  = R0;
    Y(2)  = T0;
    Y(3)  = P0;
    EPS   = E0;
    DEL   = D0;
    FKC   = F0;
    Y(4)  = cos( RAD * (EPS) ) * cos( RAD * (DEL) );
    Y(5)  = cos( RAD * (EPS) ) * sin( RAD * (DEL) );
    Y(6)  = sin( RAD * (EPS) );
    Y(7)  = 0.0;
    Y(8)  = 0.0;
    % disp([Y,EPS,DEL]);

    L       = 0;
    LL      = 0;
    NN      = 0;
    NLOOP   = 0;
    ERR0  = max([ERRR ERRA]);
    ERRR  = ERRR / ERR0;
    ERRA  = ERRA / ERR0;

    %* Derivative for Y
    [Y, F] = FUNCT(Y,F,1);

    yp20 = F(2);
    WT(1 : 8) = ERRR * abs( Y(1 : 8) + ERRA );
    SUML(1 : 8) = ( F(1 : 8) ./ WT(1 : 8) ).^2;

    SUM = 0.0;
    SUM = SUM + sum( SUML,2 );

    SUM    = sqrt( SUM );
    H      = 0.00001 * sqrt( ERR0 / SUM );
    HOLD   = 0.0;
    K      = 1;
    KOLD   = 0;
    IPHASE = 1;
    IFAIL  = 0;

    PHI(1 : 8, 1) = F(1 : 8).';
    PHI(1 : 8, 2) = zeros(8,1);
    L = 9;  %L = 9 bcs do loop increases L by one
    Y = OUT1(Y);

    for NLOOP = 0 : NLPMAX-1
        % Adams-Bashforth Predictor
        NLOOP = ADAM_B(NLOOP);
        % Adams-Moulton Corrector
        [ERR0, NLOOP] = ADAM_M(ERR0,NLOOP);

        %VOCL LOOP,SCALAR
        if LL == 0
            if IFAIL ~= 0
               L=11;
            else

                if L >= 21
                    LL = L;
                elseif H < HMIN
                    L  = 23;
                    LL = 23;
                elseif Y(1) < RRMIN
                    L  = 24;
                    LL = 24;
                elseif Y(1) > RRMAX
                    L  = 25;
                    LL = 25;
    %               ELSE IF((T0-90.0)*F(2).GT.0.0D0) THEN
    %                  L =26
    %                  LL=26
    %               ELSE IF(yp20*yp(2).lt.0.0D0) THEN
    %                  L =27
    %                  LL=27
                else
                    L = 0;
                    NN = NN + 1;
                end
            end
        end

        Y = OUT1(Y);
        if LL ~= 0
            disp(['Stop Condition: ' num2str(LL)])
            break
        end

        WT(1 : 7) = ERRR * abs( Y(1 : 7) + ERRA );
    end
    disp(['Number of LOOP=',num2str(NLOOP),', Number of calculation=',num2str(A)])
    disp(['Last interval=',num2str(H),', IFAIL=',num2str(IFAIL)])
    disp(['fq00=', num2str(F0),'rr00=',num2str(R0)])  %!for test run

end
