%************************************************************************
%      SUBROUTINE ADAM_B(NLOOP)
%*     Calculation of Adams-Bashforth Predictor
%************************************************************************
%this function is suspicted...
function [NLOOP] = ADAM_B(NLOOP)
    global Y P F ...
            H HOLD WT PHI PSIOLD ...
            PSI BETA SIGMA G ...
            K KOLD KS  ...
            ALPHA V W   %these variables are added in rewittern procedure
    G(1)   = 1.0;
    G(2)   = 0.5;
    SIGMA(1) = 1.0;

    % KS is the maximum order
    % In case step size is changed, KS->0.
    if H ~= HOLD
        KS = 0;
    end

    if KS <= KOLD
        KS = KS + 1;
    end

    if K >= KS
        PSIOLD(KS : K - 1) = PSI(KS : K - 1);
        PSI(KS) = H * KS;
        for I = KS + 1 : K
            PSI(I) = PSIOLD(I-1) + H;
        end

        %*** ALPHA
        ALPHA(KS) = 1.0 / KS;
        for I = KS + 1 : K
            ALPHA(I) = H / (PSIOLD(I-1) + H);
        end

        %*** BETA
        BETA(KS) = 1.0;
        for I = KS + 1 : K
            BETA(I) = BETA(I-1)*PSI(I-1)/PSIOLD(I-1);
        end

        %*** SIGMA
        SIGMA( KS + 1 ) = 1.0;
        for I = KS + 1 : K
            SIGMA(I+1) = I*ALPHA(I)*SIGMA(I);
        end

        %*** G (Integral of C)
        if KS == 0
            disp('Error! KS=0')
        end

        if KS == 1
            V(1 : K) = 1.0 ./ ( (1 : K) .* (2 : K + 1) );
            W(1 : K) = V(1 : K);
        else
            if K > KOLD
                V(K) = 1.0 / (K * (K + 1));
                for J= 1 : KS - 2
                    V(K-J) = V(K-J)-ALPHA(J+1)*V(K-J+1);
                end

            end
                for IQ = 1 : K + 1 - KS
                    V(IQ) = V(IQ)-ALPHA(KS)*V(IQ+1);
                    W(IQ) = V(IQ);
                end

            G(KS+1) = W(1);
        end

        for I = KS + 1 : K
            for IQ = 1 : K + 1 - I
                W(IQ) = W(IQ) - ALPHA(I) * W(IQ+1);
            end
            G(I+1) = W(1);
        end

    end

    %*** PREDICTOR
    for L=1:8

        for I=KS+1:K
            PHI(L,I) = BETA(I)*PHI(L,I);
        end
        PHI(L,K+2) = PHI(L,K+1);
        PHI(L,K+1) = 0.0;

        SUM  = 0.0;
        for I=K : -1 : 1
            SUM = SUM + G(I)*PHI(L,I);
            PHI(L,I) = PHI(L,I) + PHI(L,I+1);
        end
        P(L) = Y(L) + H * SUM;

    end
    %*** Derivative
    [P, F] = FUNCT(P,F,0);
end
