%******************************************************************
%      SUBROUTINE ADAM_M(ERR0,NLOOP)
%*     Calculation of Adams-Moulton Corrector
%************************************************************************
%      IMPLICIT REAL*8(A-H,O-Z),INTEGER*4(I-N)

function [ERR0,NLOOP] = ADAM_M(ERR0,NLOOP)
    global H WT PHI SIGMA G ...
            ERKM1 ERK K KNEW F

    GSTR = [0.500 0.0833 0.0417 0.0264 0.0188 ...
            0.0143 0.0114 0.00936 0.00789 0.00679 ...
            0.00592 0.00524 0.00468];

    KNEW  = K;

    %*** ERK, ERKM1, ERKM2
    ERK   = 0.0;
    ERKM1 = 0.0;
    ERKM2 = 0.0;
      for L = 1 : 8
         TEMP1 = 1.0 / WT(L);
         TEMP2 = F(L) - PHI(L,1);
         ERK   = ERK + (TEMP2 * TEMP1)^2;
        if K == 2
            ERKM1 = ERKM1+((PHI(L, K) + TEMP2) * TEMP1)^2;
        elseif K > 2
            ERKM1 = ERKM1+((PHI(L, K)+TEMP2)*TEMP1)^2;
            ERKM2 = ERKM2+((PHI(L,K-1)+TEMP2)*TEMP1)^2;
        end
      end

      TEMP = abs(H)*sqrt(ERK);
      ERK  = TEMP*SIGMA(K+1)*GSTR(K);

    if K == 2
        ERKM1 = abs(H) * SIGMA(K) * GSTR(K-1) * sqrt(ERKM1);
        if ERKM1 <= 0.5 * ERK
             KNEW = K - 1;
        end
    elseif K > 2
        ERKM1 = abs(H) * SIGMA(K  ) * GSTR(K-1) * sqrt(ERKM1);
        ERKM2 = abs(H) * SIGMA(K-1) * GSTR(K-2) * sqrt(ERKM2);
        if max([ERKM1 ERKM2]) <= ERK
            KNEW = K - 1;
        end
    end

%*** Validity check
      ERR   = TEMP*(G(K)-G(K+1));
    if ERR <= ERR0
        ERR0 = ADAM_UPDATE(ERR0);
    else
        ERR0 = ADAM_RETRY(ERR0);
    end
end
