%************************************************************************
%      SUBROUTINE DENSAO(PATH)
%     diffusive equilibrium(DE)
%     Aikyo-Ondo(AO) model :set the plasmapause
%************************************************************************
function [PATH] = DENSAO(PATH)
    global RAD RE XLV DLVDRR DLVDTH DLVDPH XLPP HWPP ...
            XNAO DNADRR DNADTH DNADPH

      RR     = PATH(1);     %radius [km]
      TH     = PATH(2);     %colatitude [deg]
      PH     = PATH(3);     %longitude [deg]
      COSTH  = cos(RAD * (TH));
      SINTH  = sin(RAD * (TH));
      COTTH  = 1.0 / tan(RAD * (TH));

      XLV    = RR / RE / SINTH^2;   %![RE]
      DLVDRR = XLV / RR;            %!1/RE/sin(TH)^2
      DLVDTH = - XLV * COTTH * 2.0; %![RE]
      DLVDPH = 0.0;

      XLVNRM = (XLV - XLPP) / HWPP;
      XNAO   = 0.5 - atan( XLVNRM ) / pi;

      DF1DRR = DLVDRR / (1.0 + XLVNRM^2) / HWPP / pi;
      DF1DTH = DLVDTH / (1.0 + XLVNRM^2) / HWPP / pi;
      DF1DPH = DLVDPH / (1.0 + XLVNRM^2) / HWPP / pi;

      DNADRR = -DF1DRR / XNAO;
      DNADTH = -DF1DTH / XNAO;
      DNADPH = -DF1DPH / XNAO;
%
%
end
