%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Raytracing data display program
% 2012/06/21  Takayuki Matsumuro
% Displaying figures of output_data from raytracing_main
% Propagation path and k vectors are displayed, and these figures saved
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function GRAPH1

  global prm str21

  RAD=pi/180;

  % file1 = ['result/trajectory_',num2str(prm.N),'RE_',num2str(M),'Efreq'];
  % data=load([file1 '.dat']); % load the propagation path data from the raytracing_main.m

  [nm col]=size(str21); % get the data size

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % 2. calc data
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  r=str21(:,2);
  th=str21(:,1)*RAD;
  dl=str21(:,4)*RAD;

  %if(r(1)>r(nm))
  %    save data data11.dat
  % data for displaying the propagation path
  x=r.*cos(th); y=r.*sin(th);

  xd=x(1:20:nm); yd=y(1:20:nm);
  ph=th(1:20:nm)-dl(1:20:nm);
  u=cos(ph); v=sin(ph);
  % save debug.mat

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % 3. make plot
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  figure;
  set(gca,'FontSize',18)
  set(gca,'XTick',[0 1 2 3 4 5 6])
  set(gca,'YTick',[-2 -1 0 1 2])
  set(gca,'PlotBoxAspectRatio',[1 1 1])

  axis([0 6 -2.5 2.5]);
  xlabel('[Re]'); ylabel('[Re]');
  box on
  hold on
  grid on
  %%% path %%%
  plot(x(1),y(1),'*r');
  plot(x,y,'LineWidth',1,'Color',[1 0 0]) % display propagation path
  quiver(xd,yd,u,v,'Color',[0 0 1],'AutoScaleFactor',0.5) % display k vectors


  title1 = ['trajectory',num2str(prm.N),' RE  ',num2str(round(prm.fq00,1)),'kHz'];
  title(title1)

  % text1 = ['Deg',num2str(),'°']
  % text(5,2.0,'Deg')

  %%% earth %%%
  earth=(-90:0.1:90);
  plot(cos(earth*RAD),sin(earth*RAD),'LineStyle','-','Color','Black')

  %%% latitude
  %latitude=(1:0.5:7);
  %for deg=-80:10:80
  %    plot(latitude*cos(deg*RAD),latitude*sin(deg*RAD),'LineStyle',':','Color',[0 0 0]);
  %end

  %%% display geomagetic
  for L=2:6
      bth=(-90:0.1:90);
      brr=L*cos(bth*RAD).*cos(bth*RAD);
      plt=find(abs(brr)>1);
      plot(brr(plt).*cos(bth(plt)*RAD),brr(plt).*sin(bth(plt)*RAD),'LineStyle',':','Color',[0 0 0])
  end

  %%% display plasmapause %%%
  L=prm.XLPP;
  bth=(-90:0.1:90);
  brr=L*cos(bth*RAD).*cos(bth*RAD);
  plt=find(abs(brr)>1);
  plot(brr(plt).*cos(bth(plt)*RAD),brr(plt).*sin(bth(plt)*RAD),'LineStyle','--','Color','Black')


  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % 4. save figures
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  set(0,'defaultAxesFontSize',14)
  set(0,'defaultTextFontSize',14)
  set(0,'defaultAxesFontName','Helvetica')
  set(0,'defaultTextFontName','Helvetica')

  output_file1 = ['result/trajectory_',num2str(prm.N),'RE_',num2str(round(prm.fq00,1)),'kHz.png'];
  saveas(gcf,output_file1);

  hold off
  
%   output_file2 = ['result/trajectory2_',num2str(prm.N),'RE_',num2str(prm.M),'kHz.dat'];
%   dlmwrite(output_file2, str21);


end
