%************************************************************************
%      SUBROUTINE INIT(fq00,rr00,th00,ph00,es00,dl00)

%************************************************************************
function [] = INIT()
    %%% QCONST %%%
      global PAI RAD DEG RE CVLCTY

    %%% QPARAM %%%
      global NSPEC INITED ...
      RREF RBTM RREFP ...
      PF0 GF0 ...
      XN0 THERM ETA SHINV SHINVP ...
      RRLI HWLI ...
      XLPP HWPP ...
      RRMIN RRMAX ERRR ERRA HMIN DISOUT ...
      NPATH NLPMAX ...
      % ERPP DRR1 DTH1 DPH1 DRR2 DTH2 DPH2 ...
      % INDOUT INDMSH IEOF ...
      % IYEAR IMNTH IDATE

    %%% QINIT %%%
      global  R0 T0 P0 E0 D0 F0

    %%% input_parameters from UI %%%
      global prm


    INITED = 0;
    NSPEC = 4;      % number of ion and elecron species
    PAI      = pi;
    RAD      = PAI / 180.0;
    DEG      = 1.0 / RAD;

    RE       = 6370.0;  % radius of the earth[km]
    RREF     = 7370.0;
    RREFP    = RREF;
    % RBTM     = 9370.0;
    CVLCTY   = 3.00 * 10^5; % speed of light [km]

    XME      = 9.109534 * 10^(-31);     % XME: the mass of electron
    XMP      = 1.6726485 * 10^(-27);    % XMP: the mass of proton
    QE       = 1.6021892 * 10^(-19);    % QE: the charge of electron or proton
    EP       = 8.854185 * 10^(-12);     % EP:Permittivity of vacuum
    XK       = 1.380662 * 10^(-23);     % XK:Boltzmann's constant
    GM       = 3.98603 * 10^14;         % GM: G(gravitational constant) * M (total mass of earth)

    PF0(1)   = QE^2 / 4.0 / PAI^2 / EP / XME;
    PF0(2)   = QE^2 / 4.0 / PAI^2 / EP / XMP;
    PF0(3)   = QE^2 / 4.0 / PAI^2 / EP / ( XMP * 4.0 );
    PF0(4)   = QE^2 / 4.0 / PAI^2 / EP / (XMP * 16.0);
    GF0(1)   =-QE/2.0/PAI/ XME        *1.0 * 10^(-3);
    GF0(2)   = QE/2.0/PAI/ XMP        *1.0 * 10^(-3);
    GF0(3)   = QE/2.0/PAI/(XMP * 4.0) * 1.0 * 10^(-3);
    GF0(4)   = QE/2.0/PAI/(XMP*16.0)*1.0 * 10^(-3);
    %      XN0      = 32000.0
    XN0      = 50000.0;
    %       XN0      = 4000.0
    THERM    = 1000.0;
    SHINV(2) = XMP*       (GM/RREF^2)/XK/THERM*1.0 * 10^(-3); % g(r) = GM/RREF^2
    SHINV(3) = XMP* 4.0*(GM/RREF^2)/XK/THERM*1.0 * 10^(-3);
    SHINV(4) = XMP*16.0*(GM/RREF^2)/XK/THERM*1.0 * 10^(-3);
    SHINVP   = SHINV(2);
    ETA(2)   = 0.152;
    ETA(3)   = 0.82;
    ETA(4)   = 0.025;

    %     The following parameters are used in subroutine DENSLI
    %     Following RRLI: location of the lower edge of the ionosphere
    RRLI     = 6370.0 + 90.0;
    HWLI     = 140.0;

    XLPP     = prm.XLPP; % plasmapause[Re]
    HWPP     = 0.1;
    % ERPP     = 0.2;
    % DRR1     = 5.0;
    % DTH1     = 0.05;
    % DPH1     = 0.2;
    % DRR2     = 2.5;
    % DTH2     = 0.01;
    % DPH2     = 0.1;

    %     Following RRMAX & RRMIN: Upper & lower limit of ray tracing(Km????j
    %     Following ERRR and ERRA; Initial values for the limiting error
    %       and Hmin: Limit of integration increment
    RRMAX    = 7.0*RE; %!reset Max
    RRMIN    = 6370.0;
    ERRR     = 1.0 * 10^(-5);
    ERRA     = 1.0 * 10^(-5);
    HMIN     = 1.0 * 10^(-10);
    %     Folowing DISOUT: Every this count, the output data to be printed
    DISOUT   = 50;
    %     Following NLPMAX: Maximum number of integration loops
    NLPMAX   = prm.NLPMAX;
    % INDOUT   = 20;
    % INDMSH   = 51;
    % IEOF     = -1;


    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%% Adding from the original fortran program(June,2018)
    %%% inital values at starting points
    %%% Calculate how many times the wave frequency is multiplied by the cyclotron frequency
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    %%% N: starting radial distance from the earth center [RE]
    %	rr00: starting radial distance from the earth center [km]
    %%%	th00: geomagnetic colatitude in deg latitude [deg]
    %%%	ph00: geomagnetic longitude in deg longitude [deg]
    %%%	es00: angle between the initial wave normal and geomagnetic meridian plane [deg] (Epsilon) 
    %%%	dl00: angle between the projected direction of the initial wave normal onto the geomagnetic meridial plane and the radial direction [deg] (Delta)

    N = prm.N;
    rr00 = N * 6370;
    th00 = prm.th00;
    ph00 = prm.ph00;
    dl00 = prm.dl00;
    es00 = prm.es00;


    if prm.unit_fq00 == 1
      %%% phisical constant
      e1 = 1.602 * 10^(-19);  %electric charge +e [C]
      e2 = 9.11 * 10^(-31);   %electron mass Me [kg]
      g1 = 8.07 * 10^6;       % k0 [T・km^3]
      c1 = cos( (th00/180) * (pi) );
      c2 = 1.0 + 3.0 * c1^2.0;
      b1 = g1 * sqrt(c2)/rr00^3.0; % B[T]

      Efreq = e1 * b1/ (e2 * 4.0 * acos(0) * 1.0 * 10^3 );
      % Efreq = e1 * b1 / (e2 * 1.0 * 10^3 ) ;
      %!get fceq=B*e/Me (B:magnetic field ,e:electric charge , Me:electron mass)
      M = prm.M;           %M : f= M * fceq
      fq00 = M * Efreq;    %fq00: wave frequency [kHz]
      prm.fq00 = fq00;
      % disp(['Efreq=',num2str(Efreq)])
    else
      fq00 = prm.M;       %fq00: wave frequency [kHz]
      prm.fq00 = fq00;
    end

    %...FREQ.(KHZ),GC-DIST.(KM),GM-COLAT.,GM-LONG.,EPS,DEL(DEG)
    F0 = fq00;
    R0 = rr00;
    T0 = th00;
    P0 = ph00;
    D0 = dl00;
    E0 = es00;


end
