%************************************************************************
%      SUBROUTINE REF(PATH)
%***********************************************************************
function [PATH] = REF(PATH)
    global NSPEC DEG RE FKC GMU ...
            PF0 GF0 PMU PMUS PMU0 ...
            PSI_angl COPSI  SIPSI COPSIS SIPSIS ...
            PX PY PZ ...
            PA1 PA2 PA3 ...
            PK1 PK2 PK4 PK5 ...
            PA  PB  PC  PD ...
            YR YT YP ...
            BB XNS

    PATH = DIPOLE(PATH);
    PATH = DENS(PATH);
    PX(1 : NSPEC) = PF0(1 : NSPEC) .* XNS(1 : NSPEC) / FKC^2;
    PY(1 : NSPEC) = GF0(1 : NSPEC) * BB / FKC;
    PZ(1 : NSPEC) = PY(1 : NSPEC).^2 - 1.0;

    PMU0   = sqrt(PATH(4)^2 + PATH(5)^2 + PATH(6)^2);
    COPSI  = (YR * PATH(4) + YT * PATH(5) + YP * PATH(6)) / PMU0;
    COPSIS = COPSI^2;
    SIPSIS = abs(1.0-COPSIS);
    SIPSI  = sqrt(SIPSIS);

    if abs(COPSI) > 1.0
        COPSI = 1.0;
    end
    PSI_angl    = DEG *(acos(COPSI));

    PA1 = 0.0;
    PA2 = 0.0;
    PA3 = 0.0;

    for I = 1 : NSPEC
        PA1 = PA1+PX(I);
        PA2 = PA2+PX(I)      /PZ(I);
        PA3 = PA3+PX(I)*PY(I)/PZ(I);
    end

    PK1 = 1.0 - PA1;
    PK2 = 1.0 + PA2;
    PK4 = PK1 * PK2;
    PK5 = PK2^2 - PA3^2;
    PA  = PK1 * COPSIS + PK2 * SIPSIS;
    PB  =-PK4 * (COPSIS + 1.0) - PK5 * SIPSIS;
    PC  = PK1 * PK5;
    PD  = abs(PB^2 - 4.0 * PA * PC);
    if PD < 0.0
        if PATH(1) < 6370.0 + 90.0
            PMU = 1.0;
            GMU = 1.0;
        end
    else
        PMUS = ( - PB - sqrt(PD) ) / 2.0 / PA;
%       Above is Extraordinary mode(whistler mode)
        if PMUS < 0.0
        else
            PMU = sqrt(PMUS);
            if PATH(1) < 6370.0 + 90.0
                PMU = 1.0;
                GMU = 1.0;
            end
        end
    end
end
